Le back-end — Zds Member 1.0 documentation

# Le back-end

Le terme back-end désigne la partie du code associée à Django et écrite en python. Le but du back-end est de récupérer, générer et combiner les différentes données du site afin de les envoyer au font-end.

Vous trouverez dans les liens ci-dessous une documentation spécifique à chacun d’entre eux. Vous pouvez également retrouver la documentation technique des modules ici.

- Les tutoriels et articles v2.0 (ZEP 12)
  - Vocabulaire et définitions
  - De la structure générale d’un contenu
  - Cycle de vie des contenus
  - Import de contenus
  - Aspects techniques et fonctionnels
  - Passage des tutos v1 aux tutos v2
- Les fichiers de manifeste
  - Les versions du manifeste
- Les forums
  - Le découpage des forums
  - La modération des forums
  - Les filtres sur les sujets
  - Suivre un sujet
- Les galeries
  - Généralités
  - Lien galerie <-> Tutoriel
  - Aspects techniques
  - Outils logiciels utilisés
- Les membres
  - Inscription
  - Désinscription
  - Les membres dans les environnement de test et de développement
- Les messages privés
  - Envoi et participation
- La recherche
  - L’indexation des données
  - La recherche
  - Dans le code ?
  - Quels sont les fichiers de configuration importants ?